@@ -415,6 +415,7 @@ class TestParseTransaction(TestCase):
         input = '''
 <STMTTRN>
  <TRNTYPE>POS
+ <DTUSER>20090131
  <DTPOSTED>20090401122017.000[-5:EST]
  <TRNAMT>-6.60
  <FITID>0000123456782009040100001
@@ -427,6 +428,7 @@ class TestParseTransaction(TestCase):
         self.assertEqual('pos', transaction.type)
         self.assertEqual(datetime(
             2009, 4, 1, 12, 20, 17) - timedelta(hours=-5), transaction.date)
+        self.assertEqual(datetime(2009, 1, 31, 0, 0), transaction.user_date)
         self.assertEqual(Decimal('-6.60'), transaction.amount)
         self.assertEqual('0000123456782009040100001', transaction.id)
         self.assertEqual("MCDONALD'S #112", transaction.payee)
@@ -493,6 +495,38 @@ class TestParseTransaction(TestCase):
         transaction = OfxParser.parseTransaction(txn.find('stmttrn'))
         self.assertEqual(Decimal('-1006.60'), transaction.amount)
 
+    def testThatParseTransactionWithLeadingPlusSign(self):
+        " Parse numbers with a leading '+' sign. "
+        input = '''
+<STMTTRN>
+ <TRNTYPE>POS
+ <DTPOSTED>20090401122017.000[-5:EST]
+ <TRNAMT>+1,006.60
+ <FITID>0000123456782009040100001
+ <NAME>MCDONALD'S #112
+ <MEMO>POS MERCHANDISE;MCDONALD'S #112
+</STMTTRN>
+'''
+        txn = soup_maker(input)
+        transaction = OfxParser.parseTransaction(txn.find('stmttrn'))
+        self.assertEqual(Decimal('1006.60'), transaction.amount)
+
+    def testThatParseTransactionWithSpaces(self):
+        " Parse numbers with a space separating the thousands. "
+        input = '''
+<STMTTRN>
+ <TRNTYPE>POS
+ <DTPOSTED>20090401122017.000[-5:EST]
+ <TRNAMT>+1 006,60
+ <FITID>0000123456782009040100001
+ <NAME>MCDONALD'S #112
+ <MEMO>POS MERCHANDISE;MCDONALD'S #112
+</STMTTRN>
+'''
+        txn = soup_maker(input)
+        transaction = OfxParser.parseTransaction(txn.find('stmttrn'))
+        self.assertEqual(Decimal('1006.60'), transaction.amount)
+
     def testThatParseTransactionWithNullAmountIgnored(self):
         """A null transaction value is converted to 0.
 
@@ -852,7 +886,7 @@ class TestTDAmeritrade(TestCase):
         account = ofx.accounts[0]
         statement = account.statement
         positions = statement.positions
-        self.assertEquals(len(positions), 2)
+        self.assertEqual(len(positions), 2)
 
         expected_positions = [
             {
@@ -981,6 +1015,14 @@ class TestGracefulFailures(TestCase):
         with open_file('fail_nice/empty_balance.ofx') as f:
             self.assertRaises(OfxParserException, OfxParser.parse, f)
 
+    def testErrorInTransactionList(self):
+        """There is an error in the transaction list."""
+        with open_file('error_message.ofx') as f:
+            ofx = OfxParser.parse(f, False)
+        self.assertEqual(ofx.status['code'], 2000)
+        self.assertEqual(ofx.status['severity'], 'ERROR')
+        self.assertEqual(ofx.status['message'], 'General Server Error')
+
 
 class TestParseSonrs(TestCase):
 
